#!/bin/bash

IP=$(ip route get 8.8.8.8 | awk -F"src " 'NR==1{split($2,a," ");print a[1]}')
INTERFACE=$(ip route get 8.8.8.8 | awk -F"dev " 'NR==1{split($2,a," ");print a[1]}')

IFS="."
read ip1 ip2 ip3 ip4 <<< "$IP"
VIP="$ip1.$ip2.$ip3.233" # virtual ip addr


sudo swapoff -a # turn off swap memory
# put load balancer pod spec in the manifests directory
sudo docker run --network host --rm ghcr.io/kube-vip/kube-vip:main manifest pod \
--vip "$VIP" \
--interface "$INTERFACE" \
--arp \
--controlplane \
--leaderElection | sudo tee /etc/kubernetes/manifests/vip.yaml

# load up endpoint in the config file

# apiServerCertSANs:
# controlPlaneEndpoint:
# advertiseAddress:
configFile="kubeadm-config.yaml"
newIP="$VIP"
key="apiServerCertSANs"
sed -r "s/^(\s*${key}\s*:\s*).*/\1${newIP}/" -i "$configFile"
key="controlPlaneEndpoint"
sed -r "s/^(\s*${key}\s*:\s*).*/\1${newIP}/" -i "$configFile"
key="advertiseAddress"
sed -r "s/^(\s*${key}\s*:\s*).*/\1${newIP}/" -i "$configFile"

# exit 0

sudo kubeadm init --config kubeadm-config.yaml --upload-certs

if [[ $? -ne 0 ]] ; then
  # some error
  echo "Error! Stopping cluster set up"
  exit 1
fi

mkdir -p $HOME/.kube
sudo cp -f /etc/kubernetes/admin.conf $HOME/.kube/config
sudo chown $(id -u):$(id -g) $HOME/.kube/config

kubectl apply -f flannel.yml
kubectl taint nodes --all node-role.kubernetes.io/master-


# create control-plane join command and copy it to clip
echo "------------------------------------------"
newKey=$(sudo kubeadm init phase upload-certs --upload-certs | sed -n '3~0p')
echo "$(kubeadm token create --print-join-command) --control-plane --certificate-key $newKey" | xclip -sel clip
exit 0
